@@ -306,7 +306,7 @@ class ProgramsMachine(MachineABC):
         time_interp.append(time_interp[-1]
                            + self.circumference / (beta_interp[0] * c.c))
 
-        nturns = self.dturns * (self.nprofiles - 1) + 1
+        nturns = self.dturns * self.nprofiles
         self.i0 = self.machine_ref_frame * self.dturns
         i = 0
         turn = self.i0
